@@ -64,4 +64,7 @@
 #define lzo1f_decompress_asm_safe           0
 
 
-/* vim:set ts=4 sw=4 et: */
+/*
+vi:ts=4:et
+*/
+
