@@ -2,7 +2,7 @@
 
    This file is part of the LZO real-time data compression library.
 
-   Copyright (C) 1996-2017 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 1996-2014 Markus Franz Xaver Johannes Oberhumer
    All Rights Reserved.
 
    The LZO library is free software; you can redistribute it and/or
@@ -211,9 +211,9 @@ memcpy_x_compress       ( const lzo_bytep src, lzo_uint  src_len,
                                 lzo_bytep dst, lzo_uintp dst_len,
                                 lzo_voidp wrkmem )
 {
-    lzo_memcpy(dst, src, src_len);
+    lzo_memcpy(dst,src,src_len);
     *dst_len = src_len;
-    LZO_UNUSED(wrkmem);
+    if (wrkmem) wrkmem = 0; /* avoid warning */
     return 0;
 }
 
@@ -223,9 +223,10 @@ memset_x_compress       ( const lzo_bytep src, lzo_uint  src_len,
                                 lzo_bytep dst, lzo_uintp dst_len,
                                 lzo_voidp wrkmem )
 {
-    lzo_memset(dst, 0, src_len);
+    lzo_memset(dst,0,src_len);
     *dst_len = src_len;
-    LZO_UNUSED(src); LZO_UNUSED(wrkmem);
+    if (src) src = 0;       /* avoid warning */
+    if (wrkmem) wrkmem = 0; /* avoid warning */
     return 0;
 }
 
@@ -238,9 +239,9 @@ adler32_x_compress      ( const lzo_bytep src, lzo_uint  src_len,
     lzo_uint32_t adler;
     adler = lzo_adler32(0, NULL, 0);
     adler = lzo_adler32(adler, dst, src_len);
-    LZO_UNUSED_RESULT(adler);
     *dst_len = src_len;
-    LZO_UNUSED(src); LZO_UNUSED(wrkmem);
+    if (src) src = 0;       /* avoid warning */
+    if (wrkmem) wrkmem = 0; /* avoid warning */
     return 0;
 }
 
@@ -253,11 +254,19 @@ crc32_x_compress        ( const lzo_bytep src, lzo_uint  src_len,
     lzo_uint32_t crc;
     crc = lzo_crc32(0, NULL, 0);
     crc = lzo_crc32(crc, dst, src_len);
-    LZO_UNUSED_RESULT(crc);
     *dst_len = src_len;
-    LZO_UNUSED(src); LZO_UNUSED(wrkmem);
+    if (src) src = 0;       /* avoid warning */
+    if (wrkmem) wrkmem = 0; /* avoid warning */
     return 0;
 }
 
 
-/* vim:set ts=4 sw=4 et: */
+#if defined(__LZO_PROFESSIONAL__)
+#  include "lzopro/t_wrap.ch"
+#endif
+
+
+/*
+vi:ts=4:et
+*/
+
